import { micromark } from 'micromark'
import { gfmHtml, gfm} from 'micromark-extension-gfm'
import { fromMarkdown } from 'mdast-util-from-markdown'
import { directive, directiveHtml } from 'micromark-extension-directive'
import {directiveFromMarkdown} from 'mdast-util-directive'
import {gfmFromMarkdown} from 'mdast-util-gfm'
import extension from './extension'
import type { RendererOption } from '../type'

const renderer = function(text,options:RendererOption){
    const extensions = extension(options)
    return micromark(text,{
        allowDangerousHtml: true,
        extensions: [
            gfm(),
            directive()
        ],
        htmlExtensions: [
            gfmHtml(),
            directiveHtml(extensions)
        ]
      })
}

export default renderer;

export const rendererToAst = (text) => {
    const tree = fromMarkdown(text, {
        extensions: [
            gfm(),
            directive()
        ],
        mdastExtensions:[
            gfmFromMarkdown(),
            directiveFromMarkdown()
        ]
    });
    return tree
}